@@ -341,6 +341,11 @@ int CFileZillaEnginePrivate::List(CListCommand const& command)
 	bool const refresh = (command.GetFlags() & LIST_FLAG_REFRESH) != 0;
 	bool const avoid = (command.GetFlags() & LIST_FLAG_AVOID) != 0;
 
+	if (flags & LIST_FLAG_CLEARCACHE) {
+		GetDirectoryCache().InvalidateServer(controlSocket_->GetCurrentServer());
+		GetPathCache().InvalidateServer(controlSocket_->GetCurrentServer());
+	}
+
 	if (!refresh && !command.GetPath().empty()) {
 		CServer const& server = controlSocket_->GetCurrentServer();
 		if (server) {
@@ -662,6 +667,19 @@ void CFileZillaEnginePrivate::OnCommandEvent()
 			case Command::chmod:
 				res = Chmod(static_cast<CChmodCommand const&>(command));
 				break;
+			case Command::httrequest:
+				{
+					auto * http_socket = dynamic_cast<CHttpControlSocket*>(controlSocket_.get());
+					if (http_socket) {
+						http_socket->FileTransfer(static_cast<CHttpRequestCommand const&>(command));
+						res = FZ_REPLY_CONTINUE;
+					}
+					else {
+						m_pLogging->LogMessage(MessageType::Error, _("Command not supported by this protocol"));
+						res = FZ_REPLY_NOTSUPPORTED;
+					}
+				}
+				break;
 			default:
 				res = FZ_REPLY_SYNTAXERROR;
 			}
