@@ -1,6 +1,8 @@
 #ifndef FILEZILLA_ENGINE_COMMANDS_HEADER
 #define FILEZILLA_ENGINE_COMMANDS_HEADER
 
+#include <libfilezilla/uri.hpp>
+
 // See below for actual commands and their parameters
 
 // Command IDs
@@ -18,12 +20,16 @@ enum class Command
 	rename,
 	chmod,
 	raw,
+	httrequest, // Only used by HTTP protocol
 
 	// Only used internally
 	cwd,
 	private1,
 	private2,
-	private3
+	private3,
+	private4,
+	private5,
+	private6,
 };
 
 // Reply codes
@@ -113,6 +119,7 @@ typedef CBasicCommand<Command::disconnect> CDisconnectCommand;
 #define LIST_FLAG_AVOID 2
 #define LIST_FLAG_FALLBACK_CURRENT 4
 #define LIST_FLAG_LINK 8
+#define LIST_FLAG_CLEARCACHE 16
 class CListCommand final : public CCommandHelper<CListCommand, Command::list>
 {
 	// Without a given directory, the current directory will be listed.
@@ -179,6 +186,21 @@ protected:
 	t_transferSettings const m_transferSettings;
 };
 
+class CHttpRequestCommand final : public CCommandHelper<CHttpRequestCommand, Command::httrequest>
+{
+public:
+	// Reply body is delivered through nId_data notifications
+	CHttpRequestCommand(fz::uri const& uri, std::string const& verb = std::string("GET"), std::string const& body = std::string())
+		: uri_(uri)
+		, verb_(verb)
+		, body_(body)
+	{}
+
+	fz::uri const uri_;
+	std::string const verb_;
+	std::string const body_;
+};
+
 class CRawCommand final : public CCommandHelper<CRawCommand, Command::raw>
 {
 public:
