@@ -297,6 +297,12 @@ void CSiteManagerSite::SetControlVisibility(ServerProtocol protocol, LogonType t
 		// @translator: Keep short
 		userHint = _("Project (or tenant) name or ID");
 		break;
+	case B2:
+		// @translator: Keep short
+		userLabel = _("&Account ID:");
+		// @translator: Keep short
+		passLabel = _("Application &Key:");
+		break;
 	default:
 		break;
 	}
@@ -457,13 +463,19 @@ void CSiteManagerSite::SetControlVisibility(ServerProtocol protocol, LogonType t
 void CSiteManagerSite::SetLogonTypeCtrlState()
 {
 	LogonType const t = GetLogonType();
-	xrc_call(*this, "ID_USER", &wxTextCtrl::Enable, t != LogonType::anonymous);
-	xrc_call(*this, "ID_PASS", &wxTextCtrl::Enable, t == LogonType::normal || t == LogonType::account);
-	xrc_call(*this, "ID_ACCOUNT", &wxTextCtrl::Enable, t == LogonType::account);
-	xrc_call(*this, "ID_KEYFILE", &wxTextCtrl::Enable, t == LogonType::key);
-	xrc_call(*this, "ID_KEYFILE_BROWSE", &wxButton::Enable, t == LogonType::key);
-	xrc_call(*this, "ID_ENCRYPTIONKEY", &wxTextCtrl::Enable, t == LogonType::normal);
-	xrc_call(*this, "ID_ENCRYPTIONKEY_GENERATE", &wxButton::Enable, t == LogonType::normal);
+	xrc_call(*this, "ID_USER", &wxTextCtrl::Enable, !predefined_ && t != LogonType::anonymous);
+	xrc_call(*this, "ID_PASS", &wxTextCtrl::Enable, !predefined_ && t == LogonType::normal || t == LogonType::account);
+	xrc_call(*this, "ID_ACCOUNT", &wxTextCtrl::Enable, !predefined_ && t == LogonType::account);
+	xrc_call(*this, "ID_KEYFILE", &wxTextCtrl::Enable, !predefined_ && t == LogonType::key);
+	xrc_call(*this, "ID_KEYFILE_BROWSE", &wxButton::Enable, !predefined_ && t == LogonType::key);
+	xrc_call(*this, "ID_ENCRYPTIONKEY", &wxTextCtrl::Enable, !predefined_ && t == LogonType::normal);
+	xrc_call(*this, "ID_ENCRYPTIONKEY_GENERATE", &wxButton::Enable, !predefined_ && t == LogonType::normal);
+
+	for (int i = 0; i < ParameterSection::section_count; ++i) {
+		for (auto & pair : extraParameters_[i]) {
+			pair.second->Enable(!predefined_);
+		}
+	}
 }
 
 LogonType CSiteManagerSite::GetLogonType() const
@@ -702,7 +714,7 @@ void CSiteManagerSite::UpdateSite(Site &site)
 
 	if (site.server_.credentials.encrypted_) {
 		if (!pw.empty()) {
-			site.server_.credentials.encrypted_ = public_key();
+			site.server_.credentials.encrypted_ = fz::public_key();
 			site.server_.credentials.SetPass(pw);
 		}
 	}
@@ -719,7 +731,7 @@ void CSiteManagerSite::UpdateSite(Site &site)
 	std::wstring const serverType = xrc_call(*this, "ID_SERVERTYPE", &wxChoice::GetStringSelection).ToStdWstring();
 	site.server_.server.SetType(CServer::GetServerTypeFromName(serverType));
 
-	site.m_default_bookmark.m_localDir = xrc_call(*this, "ID_LOCALDIR", &wxTextCtrl::GetValue);
+	site.m_default_bookmark.m_localDir = xrc_call(*this, "ID_LOCALDIR", &wxTextCtrl::GetValue).ToStdWstring();
 	site.m_default_bookmark.m_remoteDir = CServerPath();
 	site.m_default_bookmark.m_remoteDir.SetType(site.server_.server.GetType());
 	site.m_default_bookmark.m_remoteDir.SetPath(xrc_call(*this, "ID_REMOTEDIR", &wxTextCtrl::GetValue).ToStdWstring());
@@ -789,13 +801,39 @@ void CSiteManagerSite::UpdateExtraParameters(CServer & server)
 
 void CSiteManagerSite::SetSite(Site const& site, bool predefined)
 {
+	predefined_ = predefined;
+
+	xrc_call(*this, "ID_HOST", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_PORT", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_PROTOCOL", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_ENCRYPTION", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_TRANSFERMODE_ACTIVE", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_TRANSFERMODE_PASSIVE", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_TRANSFERMODE_DEFAULT", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_SYNC", &wxCheckBox::Enable, !predefined);
+	xrc_call(*this, "ID_REMOTEDIR", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_LOCALDIR", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_SERVERTYPE", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_LOGONTYPE", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_COMMENTS", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_COLOR", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_COMPARISON", &wxCheckBox::Enable, !predefined);
+	xrc_call(*this, "ID_TIMEZONE_HOURS", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_TIMEZONE_MINUTES", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_LIMITMULTIPLE", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_CHARSET_AUTO", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_CHARSET_UTF8", &wxWindow::Enable, !predefined);
+	xrc_call(*this, "ID_CHARSET_CUSTOM", &wxWindow::Enable, !predefined);
+
 	if (!site) {
 		// Empty all site information
 		xrc_call(*this, "ID_HOST", &wxTextCtrl::ChangeValue, wxString());
 		xrc_call(*this, "ID_PORT", &wxTextCtrl::ChangeValue, wxString());
 		SetProtocol(FTP);
 		xrc_call(*this, "ID_BYPASSPROXY", &wxCheckBox::SetValue, false);
-		xrc_call(*this, "ID_LOGONTYPE", &wxChoice::SetStringSelection, _("Anonymous"));
+		bool const kiosk_mode = COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) != 0;
+		auto const logonType = kiosk_mode ? LogonType::ask : LogonType::normal;
+		xrc_call(*this, "ID_LOGONTYPE", &wxChoice::SetStringSelection, GetNameFromLogonType(logonType));
 		xrc_call(*this, "ID_USER", &wxTextCtrl::ChangeValue, wxString());
 		xrc_call(*this, "ID_PASS", &wxTextCtrl::ChangeValue, wxString());
 		xrc_call(*this, "ID_PASS", &wxTextCtrl::SetHint, wxString());
@@ -805,7 +843,8 @@ void CSiteManagerSite::SetSite(Site const& site, bool predefined)
 		xrc_call(*this, "ID_COMMENTS", &wxTextCtrl::ChangeValue, wxString());
 		xrc_call(*this, "ID_COLOR", &wxChoice::Select, 0);
 
-		SetControlVisibility(FTP, LogonType::anonymous);
+		SetControlVisibility(FTP, logonType);
+		SetLogonTypeCtrlState();
 
 		xrc_call(*this, "ID_SERVERTYPE", &wxChoice::SetSelection, 0);
 		xrc_call(*this, "ID_LOCALDIR", &wxTextCtrl::ChangeValue, wxString());
@@ -816,13 +855,14 @@ void CSiteManagerSite::SetSite(Site const& site, bool predefined)
 
 		xrc_call(*this, "ID_TRANSFERMODE_DEFAULT", &wxRadioButton::SetValue, true);
 		xrc_call(*this, "ID_LIMITMULTIPLE", &wxCheckBox::SetValue, false);
+		xrc_call(*this, "ID_MAXMULTIPLE", &wxSpinCtrl::Enable, false);
 		xrc_call<wxSpinCtrl, int>(*this, "ID_MAXMULTIPLE", &wxSpinCtrl::SetValue, 1);
 
 		xrc_call(*this, "ID_CHARSET_AUTO", &wxRadioButton::SetValue, true);
 		xrc_call(*this, "ID_ENCODING", &wxTextCtrl::ChangeValue, wxString());
+		xrc_call(*this, "ID_ENCODING", &wxTextCtrl::Enable, false);
 	}
 	else {
-		xrc_call(*this, "ID_HOST", &wxWindow::Enable, !predefined);
 		xrc_call(*this, "ID_HOST", &wxTextCtrl::ChangeValue, site.server_.Format(ServerFormat::host_only));
 		unsigned int port = site.server_.server.GetPort();
 
@@ -832,27 +872,16 @@ void CSiteManagerSite::SetSite(Site const& site, bool predefined)
 		else {
 			xrc_call(*this, "ID_PORT", &wxTextCtrl::ChangeValue, wxString());
 		}
-		xrc_call(*this, "ID_PORT", &wxWindow::Enable, !predefined);
 
 		ServerProtocol protocol = site.server_.server.GetProtocol();
 		SetProtocol(protocol);
-		xrc_call(*this, "ID_PROTOCOL", &wxWindow::Enable, !predefined);
-		xrc_call(*this, "ID_ENCRYPTION", &wxWindow::Enable, !predefined);
 		xrc_call(*this, "ID_BYPASSPROXY", &wxCheckBox::SetValue, site.server_.server.GetBypassProxy());
 
-		LogonType logonType = site.server_.credentials.logonType_;
-		xrc_call(*this, "ID_USER", &wxTextCtrl::Enable, !predefined && logonType != LogonType::anonymous);
-		xrc_call(*this, "ID_PASS", &wxTextCtrl::Enable, !predefined && (logonType == LogonType::normal || logonType == LogonType::account));
-		xrc_call(*this, "ID_ACCOUNT", &wxTextCtrl::Enable, !predefined && logonType == LogonType::account);
-		xrc_call(*this, "ID_KEYFILE", &wxTextCtrl::Enable, !predefined && logonType == LogonType::key);
-		xrc_call(*this, "ID_KEYFILE_BROWSE", &wxButton::Enable, !predefined && logonType == LogonType::key);
-		xrc_call(*this, "ID_ENCRYPTIONKEY", &wxTextCtrl::Enable, !predefined && logonType == LogonType::normal);
-		xrc_call(*this, "ID_ENCRYPTIONKEY_GENERATE", &wxButton::Enable, !predefined && logonType == LogonType::normal);
+		LogonType const logonType = site.server_.credentials.logonType_;
+		xrc_call(*this, "ID_LOGONTYPE", &wxChoice::SetStringSelection, GetNameFromLogonType(logonType));
 
 		SetControlVisibility(protocol, logonType);
-
-		xrc_call(*this, "ID_LOGONTYPE", &wxChoice::SetStringSelection, GetNameFromLogonType(logonType));
-		xrc_call(*this, "ID_LOGONTYPE", &wxWindow::Enable, !predefined);
+		SetLogonTypeCtrlState();
 
 		xrc_call(*this, "ID_USER", &wxTextCtrl::ChangeValue, site.server_.server.GetUser());
 		xrc_call(*this, "ID_ACCOUNT", &wxTextCtrl::ChangeValue, site.server_.credentials.account_);
@@ -899,24 +928,15 @@ void CSiteManagerSite::SetSite(Site const& site, bool predefined)
 
 		xrc_call(*this, "ID_KEYFILE", &wxTextCtrl::ChangeValue, site.server_.credentials.keyFile_);
 		xrc_call(*this, "ID_COMMENTS", &wxTextCtrl::ChangeValue, site.m_comments);
-		xrc_call(*this, "ID_COMMENTS", &wxWindow::Enable, !predefined);
 		xrc_call(*this, "ID_COLOR", &wxChoice::Select, CSiteManager::GetColourIndex(site.m_colour));
-		xrc_call(*this, "ID_COLOR", &wxWindow::Enable, !predefined);
 
 		xrc_call(*this, "ID_SERVERTYPE", &wxChoice::SetSelection, site.server_.server.GetType());
-		xrc_call(*this, "ID_SERVERTYPE", &wxWindow::Enable, !predefined);
 		xrc_call(*this, "ID_LOCALDIR", &wxTextCtrl::ChangeValue, site.m_default_bookmark.m_localDir);
-		xrc_call(*this, "ID_LOCALDIR", &wxWindow::Enable, !predefined);
 		xrc_call(*this, "ID_REMOTEDIR", &wxTextCtrl::ChangeValue, site.m_default_bookmark.m_remoteDir.GetPath());
-		xrc_call(*this, "ID_REMOTEDIR", &wxWindow::Enable, !predefined);
-		xrc_call(*this, "ID_SYNC", &wxCheckBox::Enable, !predefined);
 		xrc_call(*this, "ID_SYNC", &wxCheckBox::SetValue, site.m_default_bookmark.m_sync);
-		xrc_call(*this, "ID_COMPARISON", &wxCheckBox::Enable, !predefined);
 		xrc_call(*this, "ID_COMPARISON", &wxCheckBox::SetValue, site.m_default_bookmark.m_comparison);
 		xrc_call<wxSpinCtrl, int>(*this, "ID_TIMEZONE_HOURS", &wxSpinCtrl::SetValue, site.server_.server.GetTimezoneOffset() / 60);
-		xrc_call(*this, "ID_TIMEZONE_HOURS", &wxWindow::Enable, !predefined);
 		xrc_call<wxSpinCtrl, int>(*this, "ID_TIMEZONE_MINUTES", &wxSpinCtrl::SetValue, site.server_.server.GetTimezoneOffset() % 60);
-		xrc_call(*this, "ID_TIMEZONE_MINUTES", &wxWindow::Enable, !predefined);
 
 		if (CServer::ProtocolHasFeature(site.server_.server.GetProtocol(), ProtocolFeature::TransferMode)) {
 			PasvMode pasvMode = site.server_.server.GetPasvMode();
@@ -929,14 +949,10 @@ void CSiteManagerSite::SetSite(Site const& site, bool predefined)
 			else {
 				xrc_call(*this, "ID_TRANSFERMODE_DEFAULT", &wxRadioButton::SetValue, true);
 			}
-			xrc_call(*this, "ID_TRANSFERMODE_ACTIVE", &wxWindow::Enable, !predefined);
-			xrc_call(*this, "ID_TRANSFERMODE_PASSIVE", &wxWindow::Enable, !predefined);
-			xrc_call(*this, "ID_TRANSFERMODE_DEFAULT", &wxWindow::Enable, !predefined);
 		}
 
-		int maxMultiple = site.server_.server.MaximumMultipleConnections();
+		int const maxMultiple = site.server_.server.MaximumMultipleConnections();
 		xrc_call(*this, "ID_LIMITMULTIPLE", &wxCheckBox::SetValue, maxMultiple != 0);
-		xrc_call(*this, "ID_LIMITMULTIPLE", &wxWindow::Enable, !predefined);
 		if (maxMultiple != 0) {
 			xrc_call(*this, "ID_MAXMULTIPLE", &wxSpinCtrl::Enable, !predefined);
 			xrc_call<wxSpinCtrl, int>(*this, "ID_MAXMULTIPLE", &wxSpinCtrl::SetValue, maxMultiple);
@@ -958,9 +974,6 @@ void CSiteManagerSite::SetSite(Site const& site, bool predefined)
 			xrc_call(*this, "ID_CHARSET_CUSTOM", &wxRadioButton::SetValue, true);
 			break;
 		}
-		xrc_call(*this, "ID_CHARSET_AUTO", &wxWindow::Enable, !predefined);
-		xrc_call(*this, "ID_CHARSET_UTF8", &wxWindow::Enable, !predefined);
-		xrc_call(*this, "ID_CHARSET_CUSTOM", &wxWindow::Enable, !predefined);
 		xrc_call(*this, "ID_ENCODING", &wxTextCtrl::Enable, !predefined && site.server_.server.GetEncodingType() == ENCODING_CUSTOM);
 		xrc_call(*this, "ID_ENCODING", &wxTextCtrl::ChangeValue, site.server_.server.GetCustomEncoding());
 	}
@@ -1008,7 +1021,6 @@ void CSiteManagerSite::OnLogontypeSelChanged(wxCommandEvent&)
 {
 	LogonType const t = GetLogonType();
 	SetControlVisibility(GetProtocol(), t);
-
 	SetLogonTypeCtrlState();
 }
 
