@@ -317,11 +317,13 @@ bool CState::SetLocalDir(CLocalPath const& dir, std::wstring *error, bool rememb
 #ifdef __WXMSW__
 		if (dir.GetPath() == _T("\\")) {
 			m_previouslyVisitedLocalSubdir = m_localDir.GetPath();
-			m_previouslyVisitedLocalSubdir.RemoveLast();
+			m_previouslyVisitedLocalSubdir.pop_back();
 		}
 		else
 #endif
+		{
 			m_previouslyVisitedLocalSubdir = m_localDir.GetLastSegment();
+		}
 	}
 	else {
 		m_previouslyVisitedLocalSubdir.clear();
@@ -1282,7 +1284,7 @@ CServerPath CState::GetSynchronizedDirectory(CLocalPath local_path)
 	return remote_path;
 }
 
-bool CState::RefreshRemote()
+bool CState::RefreshRemote(bool clear_cache)
 {
 	if (!m_pCommandQueue) {
 		return false;
@@ -1292,7 +1294,12 @@ bool CState::RefreshRemote()
 		return false;
 	}
 
-	return ChangeRemoteDir(GetRemotePath(), _T(""), LIST_FLAG_REFRESH);
+	int flags = LIST_FLAG_REFRESH;
+	if (clear_cache) {
+		flags |= LIST_FLAG_CLEARCACHE;
+	}
+
+	return ChangeRemoteDir(GetRemotePath(), std::wstring(), flags);
 }
 
 bool CState::GetSecurityInfo(CCertificateNotification *& pInfo)
